@@ -12,6 +12,7 @@ import (
 	"github.com/dundee/gdu/v5/internal/common"
 	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
+	"github.com/dundee/gdu/v5/report"
 	"github.com/dundee/gdu/v5/stdout"
 	"github.com/dundee/gdu/v5/tui"
 	"github.com/gdamore/tcell/v2"
@@ -22,6 +23,7 @@ import (
 type UI interface {
 	ListDevices(getter device.DevicesInfoGetter) error
 	AnalyzePath(path string, parentDir *analyze.Dir) error
+	ReadAnalysis(input io.Reader) error
 	SetIgnoreDirPaths(paths []string)
 	SetIgnoreDirPatterns(paths []string) error
 	SetIgnoreHidden(value bool)
@@ -31,6 +33,8 @@ type UI interface {
 // Flags define flags accepted by Run
 type Flags struct {
 	LogFile           string
+	InputFile         string
+	OutputFile        string
 	IgnoreDirs        []string
 	IgnoreDirPatterns []string
 	MaxCores          int
@@ -71,7 +75,10 @@ func (a *App) Run() error {
 	log.SetOutput(f)
 
 	path := a.getPath()
-	ui := a.createUI()
+	ui, err := a.createUI()
+	if err != nil {
+		return err
+	}
 
 	if err := a.setNoCross(path); err != nil {
 		return err
@@ -116,9 +123,29 @@ func (a *App) setMaxProcs() {
 	log.Printf("Max cores set to %d", runtime.GOMAXPROCS(0))
 }
 
-func (a *App) createUI() UI {
+func (a *App) createUI() (UI, error) {
 	var ui UI
 
+	if a.Flags.OutputFile != "" {
+		var output io.Writer
+		var err error
+		if a.Flags.OutputFile == "-" {
+			output = os.Stdout
+		} else {
+			output, err = os.OpenFile(a.Flags.OutputFile, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0644)
+			if err != nil {
+				return nil, fmt.Errorf("opening output file: %w", err)
+			}
+		}
+		ui = report.CreateExportUI(
+			a.Writer,
+			output,
+			!a.Flags.NoColor && a.Istty,
+			!a.Flags.NoProgress && a.Istty,
+		)
+		return ui, nil
+	}
+
 	if a.Flags.NonInteractive || !a.Istty {
 		ui = stdout.CreateStdoutUI(
 			a.Writer,
@@ -134,7 +161,7 @@ func (a *App) createUI() UI {
 		}
 		tview.Styles.BorderColor = tcell.ColorDefault
 	}
-	return ui
+	return ui, nil
 }
 
 func (a *App) setNoCross(path string) error {
@@ -154,6 +181,21 @@ func (a *App) runAction(ui UI, path string) error {
 		if err := ui.ListDevices(a.Getter); err != nil {
 			return fmt.Errorf("loading mount points: %w", err)
 		}
+	} else if a.Flags.InputFile != "" {
+		var input io.Reader
+		var err error
+		if a.Flags.InputFile == "-" {
+			input = os.Stdin
+		} else {
+			input, err = os.OpenFile(a.Flags.InputFile, os.O_RDONLY, 0644)
+			if err != nil {
+				return fmt.Errorf("opening input file: %w", err)
+			}
+		}
+
+		if err := ui.ReadAnalysis(input); err != nil {
+			return fmt.Errorf("reading analysis: %w", err)
+		}
 	} else {
 		if err := ui.AnalyzePath(path, nil); err != nil {
 			return fmt.Errorf("scanning dir: %w", err)
