@@ -32,6 +32,8 @@ func init() {
 	af = &app.Flags{}
 	flags := rootCmd.Flags()
 	flags.StringVarP(&af.LogFile, "log-file", "l", "/dev/null", "Path to a logfile")
+	flags.StringVarP(&af.OutputFile, "output-file", "o", "", "Export all info into file as JSON")
+	flags.StringVarP(&af.InputFile, "input-file", "f", "", "Import analysis from JSON file")
 	flags.IntVarP(&af.MaxCores, "max-cores", "m", runtime.NumCPU(), fmt.Sprintf("Set max cores that GDU will use. %d cores available", runtime.NumCPU()))
 	flags.BoolVarP(&af.ShowVersion, "version", "v", false, "Print version")
 
@@ -61,7 +63,7 @@ func runE(command *cobra.Command, args []string) error {
 
 	var termApp *tview.Application
 
-	if !af.ShowVersion && !af.NonInteractive && istty {
+	if !af.ShowVersion && !af.NonInteractive && istty && af.OutputFile == "" {
 		screen, err := tcell.NewScreen()
 		if err != nil {
 			return fmt.Errorf("Error creating screen: %w", err)
