@@ -2,6 +2,7 @@ package stdout
 
 import (
 	"bytes"
+	"os"
 	"testing"
 
 	log "github.com/sirupsen/logrus"
@@ -86,7 +87,6 @@ func TestItemRows(t *testing.T) {
 	err := ui.AnalyzePath("test_dir", nil)
 
 	assert.Nil(t, err)
-	assert.Contains(t, output.String(), "TiB")
 	assert.Contains(t, output.String(), "GiB")
 	assert.Contains(t, output.String(), "MiB")
 	assert.Contains(t, output.String(), "KiB")
@@ -128,11 +128,63 @@ func TestShowDevicesWithColor(t *testing.T) {
 	assert.Contains(t, output.String(), "xxx")
 }
 
+func TestReadAnalysisWithColor(t *testing.T) {
+	input, err := os.OpenFile("../internal/testdata/test.json", os.O_RDONLY, 0644)
+	assert.Nil(t, err)
+
+	output := bytes.NewBuffer(make([]byte, 10))
+
+	ui := CreateStdoutUI(output, true, true, true)
+	err = ui.ReadAnalysis(input)
+
+	assert.Nil(t, err)
+	assert.Contains(t, output.String(), "main.go")
+}
+
+func TestReadAnalysisBw(t *testing.T) {
+	input, err := os.OpenFile("../internal/testdata/test.json", os.O_RDONLY, 0644)
+	assert.Nil(t, err)
+
+	output := bytes.NewBuffer(make([]byte, 10))
+
+	ui := CreateStdoutUI(output, false, false, false)
+	err = ui.ReadAnalysis(input)
+
+	assert.Nil(t, err)
+	assert.Contains(t, output.String(), "main.go")
+}
+
+func TestReadAnalysisWithWrongFile(t *testing.T) {
+	input, err := os.OpenFile("../internal/testdata/wrong.json", os.O_RDONLY, 0644)
+	assert.Nil(t, err)
+
+	output := bytes.NewBuffer(make([]byte, 10))
+
+	ui := CreateStdoutUI(output, true, true, true)
+	err = ui.ReadAnalysis(input)
+
+	assert.NotNil(t, err)
+}
+
 func TestMaxInt(t *testing.T) {
 	assert.Equal(t, 5, maxInt(2, 5))
 	assert.Equal(t, 4, maxInt(4, 2))
 }
 
+func TestFormatSize(t *testing.T) {
+	output := bytes.NewBuffer(make([]byte, 10))
+
+	ui := CreateStdoutUI(output, true, true, true)
+
+	assert.Contains(t, ui.formatSize(1), "B")
+	assert.Contains(t, ui.formatSize(1<<10+1), "KiB")
+	assert.Contains(t, ui.formatSize(1<<20+1), "MiB")
+	assert.Contains(t, ui.formatSize(1<<30+1), "GiB")
+	assert.Contains(t, ui.formatSize(1<<40+1), "TiB")
+	assert.Contains(t, ui.formatSize(1<<50+1), "PiB")
+	assert.Contains(t, ui.formatSize(1<<60+1), "EiB")
+}
+
 // func printBuffer(buff *bytes.Buffer) {
 // 	for i, x := range buff.String() {
 // 		println(i, string(x))
